Documentation
¶
Index ¶
- Constants
- Variables
- func CacheDir(appName string) (string, error)
- func CheckDestination(dest string) (bool, error)
- func ConfigDir(appName string) (string, error)
- func DataDir(appName string) (string, error)
- func Find(path string) (string, bool, error)
- func Pick(query string, candidates []Candidate, options ...picker.Option) (int, bool, error)
- func Run(args []string, stdout io.Writer, stderr io.Writer, deps CliDependencies) error
- func WriteFile(path string, data []byte, perm os.FileMode) error
- func ZshInitSnippet() string
- type App
- type Candidate
- type CliDependencies
- type Cloner
- type ClonerFunc
- type Entry
- type Option
- type Picker
- type PickerFunc
- type Prunable
- type Pruner
- type PrunerFunc
- type Refreshable
- type Refresher
- type RefresherFunc
- type Repo
- type Runner
- type RunnerFunc
- type Source
- type Trackable
Constants ¶
const ( CandidateMetaLabel = "label" CandidateMetaKind = "kind" CandidateMetaPath = "path" CandidateMetaName = "name" CandidateMetaFullName = "full_name" CandidateMetaSSHURL = "ssh_url" CandidateMetaSource = "source" CandidateSourceLocal = "local" CandidateSourceRemote = "remote" CandidateSourceZoxide = "zoxide" CandidateSignalZoxideScore = "source.zoxide.score" )
const ( CloneToCWDFlag = "-c" CloneToCWDLongFlag = "--cwd" Usage = "usage: fly [query] | fly -c [query] | fly init | fly refresh | fly track" )
Variables ¶
var ErrNoReposTracked = errors.New("no repos tracked yet")
var ErrUnsupportedCandidate = errors.New("unsupported candidate")
Functions ¶
func CheckDestination ¶
func ZshInitSnippet ¶
func ZshInitSnippet() string
Types ¶
type CliDependencies ¶
type ClonerFunc ¶
type PickerFunc ¶
type PrunerFunc ¶ added in v0.1.4
type PrunerFunc func()
func (PrunerFunc) Launch ¶ added in v0.1.4
func (f PrunerFunc) Launch()
type Refreshable ¶ added in v0.1.4
type RefresherFunc ¶ added in v0.1.4
type RefresherFunc func()
func (RefresherFunc) Launch ¶ added in v0.1.4
func (f RefresherFunc) Launch()
type RunnerFunc ¶
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
matchers/orderedchars
Package orderedchars matches when all query characters appear in order.
|
Package orderedchars matches when all query characters appear in order. |
|
matchers/substring
Package substring matches when the query exists as a contiguous substring.
|
Package substring matches when the query exists as a contiguous substring. |
|
sorters/minipick
Package minipick sorts matches by width and start position.
|
Package minipick sorts matches by width and start position. |
|
sorters/most_adjacent
Package most_adjacent sorts matches by their most contiguous match span.
|
Package most_adjacent sorts matches by their most contiguous match span. |
|
sources
|
|
Click to show internal directories.
Click to hide internal directories.